import { IChangedArgs } from 'phosphor-properties';
import { Widget } from 'phosphor-widget';
import { ICodeCellModel, IMarkdownCellModel, ICellModel } from './model';
import { InputAreaWidget, IInputAreaModel } from 'jupyter-js-input-area';
import { OutputAreaWidget, IOutputAreaModel } from 'jupyter-js-output-area';
/**
 * A base cell widget.
 */
export declare abstract class CellWidget extends Widget {
    constructor();
    protected _model: ICellModel;
}
/**
 * A widget for a code cell.
 */
export declare class CodeCellWidget extends CellWidget {
    /**
     * Construct a code cell widget.
     */
    constructor(model: ICodeCellModel);
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    protected updateInputArea(input: IInputAreaModel): void;
    /**
     * Update the output area, creating a new output area
     * widget and detaching the old one.
     */
    protected updateOutputArea(output: IOutputAreaModel): void;
    /**
     * Change handler for model updates.
     */
    protected modelStateChanged(sender: ICodeCellModel, args: IChangedArgs<any>): void;
    protected input: InputAreaWidget;
    protected output: OutputAreaWidget;
    protected _model: ICodeCellModel;
}
/**
 * A widget for a Markdown cell.
 *
 * #### Notes
 * Things get complicated if we want the rendered text to update
 * any time the text changes, the text editor model changes,
 * or the input area model changes.  We don't support automatically
 * updating the rendered text in all of these cases.
 */
export declare class MarkdownCellWidget extends CellWidget {
    /**
     * Construct a Markdown cell widget.
     */
    constructor(model: IMarkdownCellModel);
    /**
     * Process the input and display the rendered Markdown.
     *
     * #### Notes
     * This will remove the input widget.
     * Call [[editInput]] to restore the editor.
     */
    renderInput(): void;
    /**
     * Edit the Markdown source.
     *
     * #### Notes
     * This will remove the rendered widget.
     * Call [[renderInput]] to render the source.
     */
    editInput(): void;
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    protected updateInputArea(input: IInputAreaModel): void;
    /**
     * Update the input area, creating a new input area
     * widget and detaching the old one.
     */
    protected updateRendered(rendered: boolean): void;
    /**
     * Change handler for model updates.
     */
    protected modelStateChanged(sender: IMarkdownCellModel, args: IChangedArgs<any>): void;
    protected input: InputAreaWidget;
    protected rendered: Widget;
    protected _model: IMarkdownCellModel;
}
